if (FALSE) { # identical(tolower(Sys.getenv("NOT_CRAN")), "true")
library(odbr)
# return zone data from OD Surveys database as sf object at a given city and year
df <- read_map(
city = "Sao Paulo",
year = 2017,
harmonize = FALSE,
geometry = "zone"
)
#' # return district data from OD Surveys database as sf object at a given city and year
df <- read_map(
city = "Sao Paulo",
year = 2017,
harmonize = FALSE,
geometry = "district"
)
# return municipality data from OD Surveys database as sf object at a given city and year
df <- read_map(
city = "Sao Paulo",
year = 2017,
harmonize = FALSE,
geometry = "municipality"
)
}
Run the code above in your browser using DataLab